ControlMechanism
================

.. _ControlMechanism_Subtypes:

.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       GatingMechanism
       OptimizationControlMechanism

.. automodule:: psyneulink.core.components.mechanisms.modulatory.control.controlmechanism
   :members:
   :private-members:
   :exclude-members: Linear, random, Parameters, control_signals
